
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
// 
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

// This source file was created by a code generator.
// Please do not edit.

#include "QmfPackage.h"
#include <qmf/Schema.h>
#include <qmf/SchemaProperty.h>
#include <qmf/SchemaMethod.h>
#include <string>

using namespace std;
using namespace qmf::org::matahariproject;

void PackageDefinition::configure(::qmf::AgentSession& session)
{
    string package("org.matahariproject");

    //
    // Data: Sysconfig
    //
    data_Sysconfig = qmf::Schema(SCHEMA_TYPE_DATA, package, "Sysconfig");
    {
        qmf::SchemaProperty prop("uuid", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Host UUID");
        data_Sysconfig.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("hostname", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setIndex(true);
        prop.setDesc("Hostname");
        data_Sysconfig.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("is_postboot_configured", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_WRITE);
        prop.setDesc("Set if agent is configured.");
        data_Sysconfig.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("qmf-gen-no-crash", qmf::SCHEMA_DATA_INT);
        prop.setSubtype("abstime");
        prop.setDesc("Dummy stat to stop qmf-gen from crashing.");
        data_Sysconfig.addProperty(prop);
    }

    {
        qmf::SchemaMethod method("run_uri");
        method.setDesc("Configure system using configuration file on given uri");
        {
            qmf::SchemaProperty arg("uri", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("URI with configuration file. Same protocols as cURL are supported.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("flags", qmf::SCHEMA_DATA_INT);
            arg.setDesc("             <itemizedlist>                 <listitem>                     <para><literal>0</literal>: no flag,</para>                 </listitem>                 <listitem>                     <para><literal>1</literal>: force execution. Use this if the <literal>key</literal> is already set.</para>                 </listitem>             </itemizedlist>");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("scheme", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("File format of configuration file. Currently supported are <literal>puppet</literal> and <literal>augeas</literal>.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("key", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Key will be associated with the result of the command. The key can be used in <xref linkend='Sysconfig_is_configured' />.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("status", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Status of the call contains newline separated records. First line is 'OK' or 'FAILED'. 'FAILED' status has return code on second line. The rest of the status message is optional data that differs per scheme.");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Sysconfig.addMethod(method);
    }

    {
        qmf::SchemaMethod method("run_string");
        method.setDesc("Configure system using given configuration text. Most arguments are the same as <xref linkend='Sysconfig_run_uri' />");
        {
            qmf::SchemaProperty arg("text", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Configuration string");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("flags", qmf::SCHEMA_DATA_INT);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("scheme", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("key", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("status", qmf::SCHEMA_DATA_STRING);
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Sysconfig.addMethod(method);
    }

    {
        qmf::SchemaMethod method("query");
        method.setDesc("Perform query lookup");
        {
            qmf::SchemaProperty arg("text", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Text of the query.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("flags", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Not used now.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("scheme", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Only <literal>augeas</literal> is supported.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("data", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Result of the query.");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Sysconfig.addMethod(method);
    }

    {
        qmf::SchemaMethod method("is_configured");
        method.setDesc("Check if system is configured");
        {
            qmf::SchemaProperty arg("key", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Configuration key");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("status", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Result of command associated with the key");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Sysconfig.addMethod(method);
    }

    session.registerSchema(data_Sysconfig);

}

